@@ -12,7 +12,17 @@
 #define _NV_PROTO_H_
 
 #include "nv-misc.h"
+#include "nv-pci.h"
+#include "nv-register-module.h"
 
+
+
+
+extern const char *nv_device_name;
+extern nvidia_module_t nv_fops;
+
+void        nv_acpi_register_notifier   (nv_linux_state_t *);
+void        nv_acpi_unregister_notifier (nv_linux_state_t *);
 int         nv_acpi_init                (void);
 int         nv_acpi_uninit              (void);
 
@@ -25,9 +35,6 @@ NV_STATUS   nv_gvi_suspend              (nv_state_t *, nv_pm_action_t);
 NV_STATUS   nv_gvi_resume               (nv_state_t *, nv_pm_action_t);
 #endif
 
-int         nv_register_chrdev          (void *);
-void        nv_unregister_chrdev        (void *);
-
 NvU8        nv_find_pci_capability      (struct pci_dev *, NvU8);
 void *      nv_alloc_file_private       (void);
 void        nv_free_file_private        (nv_file_private_t *);
@@ -78,29 +85,11 @@ int         nvidia_dev_get              (NvU32, nvidia_stack_t *);
 void        nvidia_dev_put              (NvU32, nvidia_stack_t *);
 int         nvidia_dev_get_uuid         (const NvU8 *, nvidia_stack_t *);
 void        nvidia_dev_put_uuid         (const NvU8 *, nvidia_stack_t *);
-int         nvidia_dev_get_pci_info     (const NvU8 *, struct pci_dev **, NvU64 *, NvU64 *);
 int         nvidia_dev_block_gc6        (const NvU8 *, nvidia_stack_t *);
 int         nvidia_dev_unblock_gc6      (const NvU8 *, nvidia_stack_t *);
 
-int           nvidia_open           (struct inode *, struct file *);
-int           nvidia_close          (struct inode *, struct file *);
-unsigned int  nvidia_poll           (struct file *, poll_table *);
-int           nvidia_ioctl          (struct inode *, struct file *, unsigned int, unsigned long);
-
-int           nvidia_probe          (struct pci_dev *, const struct pci_device_id *);
-void          nvidia_remove         (struct pci_dev *);
-
 #if defined(CONFIG_PM)
 NV_STATUS     nv_set_system_power_state (nv_power_state_t, nv_pm_action_depth_t);
-
-int           nv_pmops_suspend          (struct device *dev);
-int           nv_pmops_resume           (struct device *dev);
-int           nv_pmops_freeze           (struct device *dev);
-int           nv_pmops_thaw             (struct device *dev);
-int           nv_pmops_restore          (struct device *dev);
-int           nv_pmops_poweroff         (struct device *dev);
-int           nv_pmops_runtime_suspend  (struct device *dev);
-int           nv_pmops_runtime_resume   (struct device *dev);
 #endif
 
 void          nvidia_modeset_suspend    (NvU32 gpuId);
@@ -108,6 +97,12 @@ void          nvidia_modeset_resume     (NvU32 gpuId);
 NvBool        nv_is_uuid_in_gpu_blacklist (const NvU8 *);
 
 NV_STATUS     nv_parse_per_device_option_string(nvidia_stack_t *sp);
-nv_linux_state_t *  find_pci(NvU32 domain, NvU8 bus, NvU8 slot, NvU8 function);
-void nv_report_error(struct pci_dev *dev, NvU32 error_number, const char *format, va_list ap);
+nv_linux_state_t * find_uuid(const NvU8 *uuid);
+void          nv_report_error(struct pci_dev *dev, NvU32 error_number, const char *format, va_list ap);
+void          nv_shutdown_adapter(nvidia_stack_t *, nv_state_t *, nv_linux_state_t *);
+void          nv_dev_free_stacks(nv_linux_state_t *);
+NvBool        nv_lock_init_locks(nvidia_stack_t *, nv_state_t *);
+void          nv_lock_destroy_locks(nvidia_stack_t *, nv_state_t *);
+void          nv_linux_add_device_locked(nv_linux_state_t *);
+void          nv_linux_remove_device_locked(nv_linux_state_t *);
 #endif /* _NV_PROTO_H_ */
