@@ -30,17 +30,12 @@
 
 void uvm_hal_volta_host_write_gpu_put(uvm_channel_t *channel, NvU32 gpu_put)
 {
-    uvm_channel_manager_t *channel_manager = channel->pool->manager;
-    uvm_gpu_t *gpu = channel_manager->gpu;
-
     // We need to add a BAR1 read if GPPut is located in sysmem. This
     // guarantees that any in-flight BAR1 writes from the CPU will have reached
     // the GPU by the time the GPU reads the updated GPPut. Read the provided
     // BAR1 mapping in channel_info.
-    if (channel_manager->conf.gpput_loc == UVM_BUFFER_LOCATION_SYS && gpu->sysmem_link < UVM_GPU_LINK_NVLINK_2) {
-        UVM_ASSERT(channel->channel_info.dummyBar1Mapping);
+    if (channel->channel_info.dummyBar1Mapping)
         UVM_GPU_READ_ONCE(*channel->channel_info.dummyBar1Mapping);
-    }
 
     UVM_GPU_WRITE_ONCE(*channel->channel_info.gpPut, gpu_put);
 
