@@ -16,7 +16,6 @@
 #include "nv-ibmnpu.h"
 #include "nv-rsync.h"
 
-#if (NV_BUILD_MODULE_INSTANCES == 0)
 #include "nv-p2p.h"
 #include "rmp2pdefines.h"
 
@@ -927,5 +926,3 @@ void nvidia_p2p_put_rsync_registers(
 }
 
 EXPORT_SYMBOL(nvidia_p2p_put_rsync_registers);
-
-#endif
